==> SyL-0.14.10.tar.gz: SyL/include/lib/WebService/Rakuten_co_jp/SyL_WebServiceRakuten_co_jpResponse.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_WebServiceRakuten_co_jpResponse.php,v 1.1 2008/03/01 05:01:22 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * WEBӥ쥹ݥ󥹥饹ʳŷ
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_WebServiceRakuten_co_jpResponse.php,v 1.1 2008/03/01 05:01:22 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_WebServiceRakuten_co_jpResponse extends SyL_WebServiceResponse
{
    /**
     * ơ̾
     *
     * @access private
     * @var string
     */
    var $status = '';
    /**
     * ơå
     *
     * @access private
     * @var string
     */
    var $status_message = '';
    /**
     * 
     *
     * @access private
     * @var array
     */
    var $args = array();

    /**
     * XMLǡƼϥɥ᥽å
     *
     * @access protected
     * @param string XMLΥѥ
     * @param string XMLΥ°
     * @param string XMLΥ
     */
    function getElement($current_path, $attribute, $text)
    {
        switch ($current_path) {
        // =============================
        // ̥إå
        // =============================
        case '/Response/header:Header/Args/Arg':  $this->args[$attribute['key']] = $attribute['value']; break;
        case '/Response/header:Header/Status':    $this->status = $text; break;
        case '/Response/header:Header/StatusMsg': $this->status_message = $text; break;
        }
    }

    /**
     * 
     *
     * @access public
     * @param string 
     * @reutrn mixed 
     */
    function getArgs($arg=null)
    {
        if ($arg !== null) {
            return isset($this->args[$arg]) ? $this->args[$arg] : null;
        } else {
            return $this->args;
        }
    }

    /**
     * 顼ȽԤ
     *
     * @access public
     * @reutrn bool 顼Ƚ
     */
    function isError()
    {
        return ($this->status != 'Success');
    }

    /**
     * ơ̾
     *
     * @access public
     * @reutrn string ơ̾
     */
    function getStatus()
    {
        return $this->status;
    }

    /**
     * ơå
     *
     * @access public
     * @reutrn string ơå
     */
    function getStatusMessage()
    {
        return $this->status_message;
    }
}

?>

==> SyL-0.15.5.tar.gz: SyL/include/lib/WebService/Rakuten_co_jp/SyL_WebServiceRakuten_co_jpResponse.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_WebServiceRakuten_co_jpResponse.php,v 1.2 2008/07/10 15:17:43 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * WEBӥ쥹ݥ󥹥饹ʳŷ
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_WebServiceRakuten_co_jpResponse.php,v 1.2 2008/07/10 15:17:43 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_WebServiceRakuten_co_jpResponse extends SyL_WebServiceResponse
{
    /**
     * ơ̾
     *
     * @access private
     * @var string
     */
    var $status = '';
    /**
     * ơå
     *
     * @access private
     * @var string
     */
    var $status_message = '';
    /**
     * 
     *
     * @access private
     * @var array
     */
    var $args = array();

    /**
     * XMLǡƼϥɥ᥽å
     *
     * @access protected
     * @param string XMLΥѥ
     * @param string XMLΥ°
     * @param string XMLΥ
     */
    function getElement($current_path, $attribute, $text)
    {
        switch ($current_path) {
        // =============================
        // ̥إå
        // =============================
        case '/Response/header:Header/Args/Arg':  $this->args[$attribute['key']] = $attribute['value']; break;
        case '/Response/header:Header/Status':    $this->status = $text; break;
        case '/Response/header:Header/StatusMsg': $this->status_message = $text; break;

        case '/Response/Header/Args/Arg':  $this->args[$attribute['key']] = $attribute['value']; break;
        case '/Response/Header/Status':    $this->status = $text; break;
        case '/Response/Header/StatusMsg': $this->status_message = $text; break;
        }
    }

    /**
     * 
     *
     * @access public
     * @param string 
     * @reutrn mixed 
     */
    function getArgs($arg=null)
    {
        if ($arg !== null) {
            return isset($this->args[$arg]) ? $this->args[$arg] : null;
        } else {
            return $this->args;
        }
    }

    /**
     * 顼ȽԤ
     *
     * @access public
     * @reutrn bool 顼Ƚ
     */
    function isError()
    {
        return ($this->status != 'Success');
    }

    /**
     * ơ̾
     *
     * @access public
     * @reutrn string ơ̾
     */
    function getStatus()
    {
        return $this->status;
    }

    /**
     * ơå
     *
     * @access public
     * @reutrn string ơå
     */
    function getStatusMessage()
    {
        return $this->status_message;
    }
}

?>
